# mgdl

![pyversions](https://img.shields.io/pypi/pyversions/mgdl.svg) ![pypi](https://img.shields.io/pypi/v/mgdl.svg) ![license](https://img.shields.io/pypi/l/mgdl.svg)

CLI Manga Downloader.

## Install

`pip install mgdl`

## Usage

`mgdl name start end path`

### Example

`mgdl naruto 10 20 /home/FR0ST1N/Downloads`

## Dependencies
* [beautifulsoup4](https://pypi.org/project/beautifulsoup4/)
* [pyprind](https://pypi.org/project/PyPrind/)

## License

 [**MIT**](https://github.com/FR0ST1N/mgdl/blob/master/LICENSE)